| create_directory_cnt | R Documentation |
Addition list content methods for sharepoint connectors implemented for
connector::create_directory_cnt():
ConnectorSharepoint: Reuses the connector::create_directory_cnt()
method for ConnectorSharepoint()
create_directory_cnt(connector_object, name, open = TRUE, ...)
## S3 method for class 'ConnectorSharepoint'
create_directory_cnt(connector_object, name, open = TRUE, ...)
connector_object |
Connector The connector object to use. |
name |
character The name of the directory to create |
open |
create a new connector object |
... |
ConnectorSharepoint: Additional parameters to pass to
|
ConnectorSharepoint object or ConnectorSharepoint object of a newly built directory
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.