download_cnt: Download content from the connector

download_cntR Documentation

Download content from the connector

Description

Addition list content methods for sharepoint connectors implemented for connector::download_cnt():

  • ConnectorSharepoint: Reuses the connector::download_cnt() method for ConnectorSharepoint()

Usage

download_cnt(connector_object, src, dest = basename(src), ...)

## S3 method for class 'ConnectorSharepoint'
download_cnt(connector_object, src, dest = basename(src), ...)

Arguments

connector_object

Connector The connector object to use.

src

The name of the file to download from SharePoint

dest

The local path to save the downloaded file

...

ConnectorSharepoint: Additional parameters to pass to the download() method of ms_drive class.

Value

ConnectorSharepoint object


connector.sharepoint documentation built on June 1, 2026, 9:07 a.m.