| download_directory_cnt | R Documentation |
Addition list content methods for sharepoint connectors implemented for
connector::download_directory_cnt():
download_directory_cnt(connector_object, src, dest = basename(src), ...)
## S3 method for class 'ConnectorSharepoint'
download_directory_cnt(
connector_object,
src,
dest = basename(src),
...,
recursive = TRUE
)
connector_object |
Connector The connector object to use. |
src |
The name of the directory to download from SharePoint |
dest |
The local directory path to save the downloaded content |
... |
additional parameters passed on to |
recursive |
If |
ConnectorSharepoint object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.