remove_cnt: Remove content from the connector

remove_cntR Documentation

Remove content from the connector

Description

Addition remove methods for sharepoint connectors implemented for connector::remove_cnt():

  • ConnectorSharepoint: Reuses the connector::remove_cnt() method for ConnectorSharepoint()

Usage

remove_cnt(connector_object, name, ...)

## S3 method for class 'ConnectorSharepoint'
remove_cnt(connector_object, name, ...)

Arguments

connector_object

Connector The connector object to use.

name

character Name of the content to read, write, or remove. Typically the table name.

...

ConnectorSharepoint: Additional parameters to pass to the delete() method of ms_drive class.

Value

ConnectorSharepoint object


connector.sharepoint documentation built on June 1, 2026, 9:07 a.m.