| remove_directory_cnt | R Documentation |
Addition list content methods for sharepoint connectors implemented for
connector::remove_directory_cnt():
ConnectorSharepoint: Reuses the connector::remove_directory_cnt()
method for ConnectorSharepoint()
remove_directory_cnt(connector_object, name, ...)
## S3 method for class 'ConnectorSharepoint'
remove_directory_cnt(connector_object, name, ...)
connector_object |
Connector The connector object to use. |
name |
character The name of the directory to remove |
... |
ConnectorSharepoint: Additional parameters to pass to
|
ConnectorSharepoint object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.