tbl_cnt: Use dplyr verbs to interact with the remote database table

tbl_cntR Documentation

Use dplyr verbs to interact with the remote database table

Description

Addition tbl methods for sharepoint connectors implemented for connector::tbl_cnt():

  • ConnectorSharepoint: Uses read_cnt() to allow redundancy.

Usage

tbl_cnt(connector_object, name, ...)

## S3 method for class 'ConnectorSharepoint'
tbl_cnt(connector_object, name, ...)

Arguments

connector_object

Connector The connector object to use.

name

character Name of the content to read, write, or remove. Typically the table name.

...

Additional arguments passed to the method for the individual connector.

Value

A dplyr::tbl object.


connector.sharepoint documentation built on June 1, 2026, 9:07 a.m.