| upload_cnt | R Documentation |
Addition list content methods for sharepoint connectors implemented for
connector::upload_cnt():
ConnectorSharepoint: Reuses the connector::upload_cnt()
method for ConnectorSharepoint()
upload_cnt(
connector_object,
src,
dest = basename(src),
overwrite = zephyr::get_option("overwrite", "connector"),
...
)
## S3 method for class 'ConnectorSharepoint'
upload_cnt(
connector_object,
src,
dest = basename(src),
overwrite = zephyr::get_option("overwrite", "connector.sharepoint"),
...,
recursive = FALSE
)
connector_object |
Connector The connector object to use. |
src |
The local file path to upload |
dest |
The destination name/path in SharePoint |
overwrite |
Overwrite existing content if it exists in the connector?
See connector-options for details. Default can be set globally with
|
... |
ConnectorSharepoint: Additional parameters to pass to
the |
recursive |
If |
ConnectorSharepoint object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.