write_cnt: Write content to the connector

write_cntR Documentation

Write content to the connector

Description

Addition write methods for sharepoint connectors implemented for connector::write_cnt():

  • ConnectorSharepoint: Reuses the connector::write_cnt() method for ConnectorSharepoint()

Usage

write_cnt(
  connector_object,
  x,
  name,
  overwrite = zephyr::get_option("overwrite", "connector"),
  ...
)

## S3 method for class 'ConnectorSharepoint'
write_cnt(
  connector_object,
  x,
  name,
  overwrite = zephyr::get_option("overwrite", "connector.sharepoint"),
  ...
)

Arguments

connector_object

Connector The connector object to use.

x

The object to write to the connection

name

character Name of the content to read, write, or remove. Typically the table name.

overwrite

Overwrite existing content if it exists in the connector? See connector-options for details. Default can be set globally with options(connector.overwrite = TRUE/FALSE) or environment variable R_CONNECTOR_OVERWRITE.. Default: FALSE.

...

ConnectorSharepoint: Additional parameters to pass to the connector::write_file() function

Value

invisible connector_object.


connector.sharepoint documentation built on June 1, 2026, 9:07 a.m.