| download_cnt | R Documentation |
Addition list content methods for sharepoint connectors implemented for
connector::download_cnt():
ConnectorSharepoint: Reuses the connector::download_cnt()
method for ConnectorSharepoint()
download_cnt(connector_object, src, dest = basename(src), ...)
## S3 method for class 'ConnectorSharepoint'
download_cnt(connector_object, src, dest = basename(src), ...)
connector_object |
Connector The connector object to use. |
src |
The name of the file to download from SharePoint |
dest |
The local path to save the downloaded file |
... |
ConnectorSharepoint: Additional parameters to pass to the
|
ConnectorSharepoint object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.