| write_cnt | R Documentation |
Addition write methods for sharepoint connectors implemented for
connector::write_cnt():
ConnectorSharepoint: Reuses the connector::write_cnt()
method for ConnectorSharepoint()
write_cnt(
connector_object,
x,
name,
overwrite = zephyr::get_option("overwrite", "connector"),
...
)
## S3 method for class 'ConnectorSharepoint'
write_cnt(
connector_object,
x,
name,
overwrite = zephyr::get_option("overwrite", "connector.sharepoint"),
...
)
connector_object |
Connector The connector object to use. |
x |
The object to write to the connection |
name |
character Name of the content to read, write, or remove. Typically the table name. |
overwrite |
Overwrite existing content if it exists in the connector?
See connector-options for details. Default can be set globally with
|
... |
ConnectorSharepoint: Additional parameters to pass to the
|
invisible connector_object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.